pub struct Response {
pub description: String,
pub headers: IndexMap<String, ReferenceOr<Header>>,
pub content: IndexMap<String, MediaType>,
pub links: IndexMap<String, ReferenceOr<Link>>,
pub extensions: IndexMap<String, Value>,
}Fields
description: StringREQUIRED. A description of the response. CommonMark syntax MAY be used for rich text representation.
headers: IndexMap<String, ReferenceOr<Header>>Maps a header name to its definition. RFC7230 states header names are case insensitive. If a response header is defined with the name “Content-Type”, it SHALL be ignored.
content: IndexMap<String, MediaType>A map containing descriptions of potential response payloads. The key is a media type or media type range and the value describes it. For responses that match multiple keys, only the most specific key is applicable. e.g. text/plain overrides text/*
links: IndexMap<String, ReferenceOr<Link>>A map of operations links that can be followed from the response. The key of the map is a short name for the link, following the naming constraints of the names for Component Objects.
extensions: IndexMap<String, Value>Inline extensions to this object.