Module operation

Module operation 

Traits and utilities for schema generation for operations (handlers).

Enums

ParamLocation
Location of an operation parameter.

Traits

OperationInput
A trait for operation input schema generation.
OperationOutput
A trait for operation output schema generation.

Functions

add_parameters
Add parameters to an operation while reporting errors.
parameters_from_schema
Generate operation parameters from a JSON schema where the schema is an object, and each property is a parameter.
set_body
Set the body of an operation while reporting errors.

Derive Macros

OperationIomacros
A helper to reduce boilerplate for implementing OperationInput and OperationOutput for common use-cases.