Scalar

Struct Scalar 

pub struct Scalar { /* private fields */ }
Available on crate feature scalar only.
A wrapper to embed Scalar in your app.

Implementations

Source

impl Scalar

pub fn axum_route<S>(&self) -> ApiMethodRouter<S>
where S: Clone + Send + Sync + 'static,

Available on crate feature axum only.

Returns an ApiMethodRouter to expose the Scalar API References.

Examples
ApiRouter::<()>::new()
    .route("/docs", Scalar::new("/openapi.json").axum_route());
pub fn axum_handler<S>( &self, ) -> impl AxumOperationHandler<(), Html<&'static str>, ((),), S>

Available on crate feature axum only.

Returns an axum Handler that can be used with API routes.

Examples
ApiRouter::<()>::new().api_route(
    "/docs",
    get_with(Scalar::new("/openapi.json").axum_handler(), |op| {
        op.description("This documentation page.")
    }),
);
Source

impl Scalar

pub fn new(spec_url: impl Into<String>) -> Self

Create a new Scalar wrapper with the given spec url.

pub fn with_title(self, title: &str) -> Self

Set the title of the Scalar page.

pub fn html(&self) -> String

Build the Scalar API References html page.