pub struct WithApi<T>(pub T::Target, pub PhantomData<T>)
where
T: ApiOverride;Expand description
Allows non OperationInput or OperationOutput types to be used in aide handlers with a provided documentation.
For types that already implement OperationInput or OperationOutput it overrides the documentation with the provided one.
See ApiOverride on how to implement such an override
Tuple Fields
0: T::Target1: PhantomData<T>Implementations
Sourceimpl<T> WithApi<T>where
T: ApiOverride,
impl<T> WithApi<T>where
T: ApiOverride,
Sourcepub fn into_inner(self) -> T::Target
pub fn into_inner(self) -> T::Target
Unwraps Self into its inner type