Traits and utilities for schema generation for operations (handlers).
Enums
- Param
Location - Location of an operation parameter.
Traits
- Operation
Input - A trait for operation input schema generation.
- Operation
Output - A trait for operation output schema generation.
Functions
- add_
parameters - Add parameters to an operation while reporting errors.
- parameters_
from_ schema - Generate operation parameters from a JSON schema where the schema is an object, and each property is a parameter.
- set_
body - Set the body of an operation while reporting errors.
Derive Macros
- Operation
Io macros - A helper to reduce boilerplate for implementing
OperationInputandOperationOutputfor common use-cases.